@@ -107,6 +107,8 @@ class CollectionVersion(Content):
         description (models.TextField): A short summary description of the collection.
         docs_blob (psql_fields.JSONField): A JSON field holding the various documentation blobs in
             the collection.
+        manifest (psql_fields.JSONField): A JSON field holding MANIFEST.json data.
+        files (psql_fields.JSONField): A JSON field holding FILES.json data.
         documentation (models.CharField): The URL to any online docs.
         homepage (models.CharField): The URL to the homepage of the collection/project.
         issues (models.CharField): The URL to the collection issue tracker.
@@ -115,6 +117,7 @@ class CollectionVersion(Content):
         namespace (models.CharField): The namespace of the collection.
         repository (models.CharField): The URL of the originating SCM repository.
         version (models.CharField): The version of the collection.
+        requires_ansible (models.CharField): The version of Ansible required to use the collection.
         is_highest (models.BooleanField): Indicates that the version is the highest one
             in the collection.
 
@@ -132,14 +135,17 @@ class CollectionVersion(Content):
     dependencies = psql_fields.JSONField(default=dict, editable=False)
     description = models.TextField(default="", blank=True, editable=False)
     docs_blob = psql_fields.JSONField(default=dict, editable=False)
+    manifest = psql_fields.JSONField(default=dict, editable=False)
+    files = psql_fields.JSONField(default=dict, editable=False)
     documentation = models.CharField(default="", blank=True, max_length=2000, editable=False)
     homepage = models.CharField(default="", blank=True, max_length=2000, editable=False)
     issues = models.CharField(default="", blank=True, max_length=2000, editable=False)
     license = psql_fields.ArrayField(models.CharField(max_length=32), default=list, editable=False)
     name = models.CharField(max_length=64, editable=False)
-    namespace = models.CharField(max_length=32, editable=False)
+    namespace = models.CharField(max_length=64, editable=False)
     repository = models.CharField(default="", blank=True, max_length=2000, editable=False)
     version = models.CharField(max_length=128, editable=False)
+    requires_ansible = models.CharField(null=True, max_length=255)
 
     is_highest = models.BooleanField(editable=False, default=False)
 
@@ -223,12 +229,18 @@ class CollectionRemote(Remote):
 class AnsibleRepository(Repository):
     """
     Repository for "ansible" content.
+
+    Fields:
+
+        last_synced_metadata_time (models.DateTimeField): Last synced metadata time.
     """
 
     TYPE = "ansible"
     CONTENT_TYPES = [Role, CollectionVersion]
     REMOTE_TYPES = [RoleRemote, CollectionRemote]
 
+    last_synced_metadata_time = models.DateTimeField(null=True)
+
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
 
